==> owncloud-8.2.2p3.tgz: owncloud/core/l10n/bn_BD.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "নিম্নোক্ত ব্যবহারকারীকে মেইল পাঠানো গেলনা: %s",
    "Turned on maintenance mode" : "রক্ষণাবেক্ষণ মোড চালু হয়েছে",
    "Turned off maintenance mode" : "রক্ষণাবেক্ষণ মোড বন্ধ হয়েছে",
    "Updated database" : "ডাটাবেজ নবায়ন করা হয়েছে",
    "No image or file provided" : "কোন ইমেজ বা ফাইল প্রদান করা হয়নি",
    "Unknown filetype" : "অজানা প্রকৃতির ফাইল",
    "Invalid image" : "অবৈধ চিত্র",
    "Sunday" : "রবিবার",
    "Monday" : "সোমবার",
    "Tuesday" : "মঙ্গলবার",
    "Wednesday" : "বুধবার",
    "Thursday" : "বৃহস্পতিবার",
    "Friday" : "শুক্রবার",
    "Saturday" : "শনিবার",
    "Sun." : "রবি.",
    "Mon." : "সোম.",
    "Tue." : "মঙ্গল.",
    "Wed." : "বুধ.",
    "Thu." : "বৃহঃ.",
    "Fri." : "শুক্র.",
    "Sat." : "শনি.",
    "January" : "জানুয়ারি",
    "February" : "ফেব্রুয়ারি",
    "March" : "মার্চ",
    "April" : "এপ্রিল",
    "May" : "মে",
    "June" : "জুন",
    "July" : "জুলাই",
    "August" : "অগাষ্ট",
    "September" : "সেপ্টেম্বর",
    "October" : "অক্টোবর",
    "November" : "নভেম্বর",
    "December" : "ডিসেম্বর",
    "Jan." : "জানু.",
    "Feb." : "ফেব্রু.",
    "Mar." : "মার্চ.",
    "Apr." : "এপ্রিল.",
    "May." : "মে.",
    "Jun." : "জুন.",
    "Jul." : "জুলাই.",
    "Aug." : "অগাস্ট.",
    "Sep." : "সেপ্টে.",
    "Oct." : "অক্টো.",
    "Nov." : "নভে.",
    "Dec." : "ডিসে.",
    "Settings" : "নিয়ামকসমূহ",
    "Saving..." : "সংরক্ষণ করা হচ্ছে..",
    "seconds ago" : "সেকেন্ড পূর্বে",
    "No" : "না",
    "Yes" : "হ্যাঁ",
    "Choose" : "বেছে নিন",
    "Ok" : "তথাস্তু",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} সাংঘর্ষিক ফাইল","{count} সাংঘর্ষিক ফাইল"],
    "One file conflict" : "একটি সাংঘর্ষিক ফাইল",
    "New Files" : "নতুন ফাইল",
    "Already existing files" : "বিদ্যমান ফাইল",
    "Which files do you want to keep?" : "কোন ফাইলগুলো রেখে দিতে চান?",
    "Cancel" : "বাতিল",
    "Continue" : "চালিয়ে যাও",
    "Strong password" : "শক্তিশালী কুটশব্দ",
    "Shared" : "ভাগাভাগিকৃত",
    "Error" : "সমস্যা",
    "Error while sharing" : "ভাগাভাগি করতে সমস্যা দেখা দিয়েছে  ",
    "Error while unsharing" : "ভাগাভাগি বাতিল করতে সমস্যা দেখা দিয়েছে",
    "Error while changing permissions" : "অনুমতিসমূহ  পরিবর্তন করতে সমস্যা দেখা দিয়েছে",
    "Error setting expiration date" : "মেয়াদোত্তীর্ণ হওয়ার তারিখ নির্ধারণ করতে সমস্যা দেখা দিয়েছে",
    "Set expiration date" : "মেয়াদোত্তীর্ণ হওয়ার তারিখ নির্ধারণ করুন",
    "Expiration date" : "মেয়াদোত্তীর্ণ হওয়ার তারিখ",
    "Sending ..." : "পাঠানো হচ্ছে......",
    "Email sent" : "ই-মেইল পাঠানো হয়েছে",
    "Resharing is not allowed" : "পূনঃরায় ভাগাভাগি অনুমোদিত নয়",
    "Share link" : "লিংক ভাগাভাগি করেন",
    "Password protect" : "কূটশব্দ সুরক্ষিত",
    "Password" : "কূটশব্দ",
    "Email link to person" : "ব্যক্তির সাথে ই-মেইল যুক্ত কর",
    "Send" : "পাঠাও",
    "Shared with you and the group {group} by {owner}" : "{owner} আপনার এবং {group} গোষ্ঠীর সাথে ভাগাভাগি করেছেন",
    "Shared with you by {owner}" : "{owner} আপনার সাথে ভাগাভাগি করেছেন",
    "Shared in {item} with {user}" : "{user} এর সাথে {item} ভাগাভাগি করা হয়েছে",
    "group" : "দল",
    "Unshare" : "ভাগাভাগি বাতিল ",
    "can share" : "ভাগাভাগি করেত পারেন",
    "can edit" : "সম্পাদনা করতে পারবেন",
    "create" : "তৈরী করুন",
    "delete" : "মুছে ফেল",
    "access control" : "অধিগম্যতা নিয়ন্ত্রণ",
    "Share" : "ভাগাভাগি কর",
    "Warning" : "সতর্কবাণী",
    "The object type is not specified." : "অবজেক্টের ধরণটি সুনির্দিষ্ট নয়।",
    "Enter new" : "নতুন লিখুন",
    "Delete" : "মুছে",
    "Add" : "যোগ কর",
    "Edit tags" : "ট্যাগ সম্পাদনা",
    "Please reload the page." : "দয়া করে পৃষ্ঠাটি পূনরায় লোড করুন।",
    "Use the following link to reset your password: {link}" : "আপনার কূটশব্দটি পূনঃনির্ধারণ  করার জন্য নিম্নোক্ত লিংকটি ব্যবহার করুনঃ {link}",
    "New password" : "নতুন কূটশব্দ",
    "New Password" : "নতুন কূটশব্দ",
    "Reset password" : "কূটশব্দ পূনঃনির্ধারণ কর",
    "Personal" : "ব্যক্তিগত",
    "Users" : "ব্যবহারকারী",
    "Apps" : "অ্যাপ",
    "Admin" : "প্রশাসন",
    "Help" : "সহায়িকা",
    "Error deleting tag(s)" : "ট্যাগ(সমূহ) অপসারণে সমস্যা",
    "Error tagging" : "ট্যাগ করতে সমস্যা",
    "Error untagging" : "ট্যাগ বাতিল করতে সমস্যা",
    "Error favoriting" : "প্রিয় তালিকাভুক্তিতে সমস্যা",
    "Access forbidden" : "অধিগমনের অনুমতি নেই",
    "File not found" : "ফাইল খুঁজে পাওয়া গেল না",
    "Cheers!" : "শুভেচ্ছা!",
    "Create an <strong>admin account</strong>" : "<strong>প্রশাসক একাউন্ট</strong> তৈরী করুন",
    "Username" : "ব্যবহারকারী",
    "Data folder" : "ডাটা ফোল্ডার ",
    "Configure the database" : "ডাটাবেচ কনফিগার করুন",
    "Database user" : "ডাটাবেজ ব্যবহারকারী",
    "Database password" : "ডাটাবেজ কূটশব্দ",
    "Database name" : "ডাটাবেজের নাম",
    "Database tablespace" : "ডাটাবেজ টেবলস্পেস",
    "Database host" : "ডাটাবেজ হোস্ট",
    "Finish setup" : "সেটআপ সুসম্পন্ন কর",
    "Finishing …" : "সম্পন্ন হচ্ছে....",
    "Log out" : "প্রস্থান",
    "Search" : "অনুসন্ধান",
    "Log in" : "প্রবেশ",
    "remember" : "মনে রাখ",
    "Alternative Logins" : "বিকল্প লগইন"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.3.tgz: owncloud/core/l10n/bn_BD.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "নিম্নোক্ত ব্যবহারকারীকে মেইল পাঠানো গেলনা: %s",
    "Turned on maintenance mode" : "রক্ষণাবেক্ষণ মোড চালু হয়েছে",
    "Turned off maintenance mode" : "রক্ষণাবেক্ষণ মোড বন্ধ হয়েছে",
    "Updated database" : "ডাটাবেজ নবায়ন করা হয়েছে",
    "No image or file provided" : "কোন ইমেজ বা ফাইল প্রদান করা হয়নি",
    "Unknown filetype" : "অজানা প্রকৃতির ফাইল",
    "Invalid image" : "অবৈধ চিত্র",
    "Sunday" : "রবিবার",
    "Monday" : "সোমবার",
    "Tuesday" : "মঙ্গলবার",
    "Wednesday" : "বুধবার",
    "Thursday" : "বৃহস্পতিবার",
    "Friday" : "শুক্রবার",
    "Saturday" : "শনিবার",
    "Sun." : "রবি.",
    "Mon." : "সোম.",
    "Tue." : "মঙ্গল.",
    "Wed." : "বুধ.",
    "Thu." : "বৃহঃ.",
    "Fri." : "শুক্র.",
    "Sat." : "শনি.",
    "January" : "জানুয়ারি",
    "February" : "ফেব্রুয়ারি",
    "March" : "মার্চ",
    "April" : "এপ্রিল",
    "May" : "মে",
    "June" : "জুন",
    "July" : "জুলাই",
    "August" : "অগাষ্ট",
    "September" : "সেপ্টেম্বর",
    "October" : "অক্টোবর",
    "November" : "নভেম্বর",
    "December" : "ডিসেম্বর",
    "Jan." : "জানু.",
    "Feb." : "ফেব্রু.",
    "Mar." : "মার্চ.",
    "Apr." : "এপ্রিল.",
    "May." : "মে.",
    "Jun." : "জুন.",
    "Jul." : "জুলাই.",
    "Aug." : "অগাস্ট.",
    "Sep." : "সেপ্টে.",
    "Oct." : "অক্টো.",
    "Nov." : "নভে.",
    "Dec." : "ডিসে.",
    "Settings" : "নিয়ামকসমূহ",
    "Saving..." : "সংরক্ষণ করা হচ্ছে..",
    "seconds ago" : "সেকেন্ড পূর্বে",
    "No" : "না",
    "Yes" : "হ্যাঁ",
    "Choose" : "বেছে নিন",
    "Ok" : "তথাস্তু",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} সাংঘর্ষিক ফাইল","{count} সাংঘর্ষিক ফাইল"],
    "One file conflict" : "একটি সাংঘর্ষিক ফাইল",
    "New Files" : "নতুন ফাইল",
    "Already existing files" : "বিদ্যমান ফাইল",
    "Which files do you want to keep?" : "কোন ফাইলগুলো রেখে দিতে চান?",
    "Cancel" : "বাতিল",
    "Continue" : "চালিয়ে যাও",
    "Strong password" : "শক্তিশালী কুটশব্দ",
    "Shared" : "ভাগাভাগিকৃত",
    "Error" : "সমস্যা",
    "Error while sharing" : "ভাগাভাগি করতে সমস্যা দেখা দিয়েছে  ",
    "Error while unsharing" : "ভাগাভাগি বাতিল করতে সমস্যা দেখা দিয়েছে",
    "Error setting expiration date" : "মেয়াদোত্তীর্ণ হওয়ার তারিখ নির্ধারণ করতে সমস্যা দেখা দিয়েছে",
    "Set expiration date" : "মেয়াদোত্তীর্ণ হওয়ার তারিখ নির্ধারণ করুন",
    "Expiration date" : "মেয়াদোত্তীর্ণ হওয়ার তারিখ",
    "Sending ..." : "পাঠানো হচ্ছে......",
    "Email sent" : "ই-মেইল পাঠানো হয়েছে",
    "Resharing is not allowed" : "পূনঃরায় ভাগাভাগি অনুমোদিত নয়",
    "Share link" : "লিংক ভাগাভাগি করেন",
    "Password protect" : "কূটশব্দ সুরক্ষিত",
    "Password" : "কূটশব্দ",
    "Email link to person" : "ব্যক্তির সাথে ই-মেইল যুক্ত কর",
    "Send" : "পাঠাও",
    "Shared with you and the group {group} by {owner}" : "{owner} আপনার এবং {group} গোষ্ঠীর সাথে ভাগাভাগি করেছেন",
    "Shared with you by {owner}" : "{owner} আপনার সাথে ভাগাভাগি করেছেন",
    "group" : "দল",
    "Unshare" : "ভাগাভাগি বাতিল ",
    "can share" : "ভাগাভাগি করেত পারেন",
    "can edit" : "সম্পাদনা করতে পারবেন",
    "create" : "তৈরী করুন",
    "delete" : "মুছে ফেল",
    "access control" : "অধিগম্যতা নিয়ন্ত্রণ",
    "Share" : "ভাগাভাগি কর",
    "Warning" : "সতর্কবাণী",
    "Delete" : "মুছে",
    "Rename" : "পূনঃনামকরণ",
    "The object type is not specified." : "অবজেক্টের ধরণটি সুনির্দিষ্ট নয়।",
    "Enter new" : "নতুন লিখুন",
    "Add" : "যোগ কর",
    "Edit tags" : "ট্যাগ সম্পাদনা",
    "Please reload the page." : "দয়া করে পৃষ্ঠাটি পূনরায় লোড করুন।",
    "Personal" : "ব্যক্তিগত",
    "Users" : "ব্যবহারকারী",
    "Apps" : "অ্যাপ",
    "Admin" : "প্রশাসন",
    "Help" : "সহায়িকা",
    "Error deleting tag(s)" : "ট্যাগ(সমূহ) অপসারণে সমস্যা",
    "Error tagging" : "ট্যাগ করতে সমস্যা",
    "Error untagging" : "ট্যাগ বাতিল করতে সমস্যা",
    "Error favoriting" : "প্রিয় তালিকাভুক্তিতে সমস্যা",
    "Access forbidden" : "অধিগমনের অনুমতি নেই",
    "File not found" : "ফাইল খুঁজে পাওয়া গেল না",
    "Cheers!" : "শুভেচ্ছা!",
    "Create an <strong>admin account</strong>" : "<strong>প্রশাসক একাউন্ট</strong> তৈরী করুন",
    "Username" : "ব্যবহারকারী",
    "Data folder" : "ডাটা ফোল্ডার ",
    "Configure the database" : "ডাটাবেচ কনফিগার করুন",
    "Database user" : "ডাটাবেজ ব্যবহারকারী",
    "Database password" : "ডাটাবেজ কূটশব্দ",
    "Database name" : "ডাটাবেজের নাম",
    "Database tablespace" : "ডাটাবেজ টেবলস্পেস",
    "Database host" : "ডাটাবেজ হোস্ট",
    "Finish setup" : "সেটআপ সুসম্পন্ন কর",
    "Finishing …" : "সম্পন্ন হচ্ছে....",
    "Log out" : "প্রস্থান",
    "Search" : "অনুসন্ধান",
    "Log in" : "প্রবেশ",
    "Alternative Logins" : "বিকল্প লগইন",
    "Use the following link to reset your password: {link}" : "আপনার কূটশব্দটি পূনঃনির্ধারণ  করার জন্য নিম্নোক্ত লিংকটি ব্যবহার করুনঃ {link}",
    "New password" : "নতুন কূটশব্দ",
    "New Password" : "নতুন কূটশব্দ",
    "Reset password" : "কূটশব্দ পূনঃনির্ধারণ কর"
},
"nplurals=2; plural=(n != 1);");
